import * as React from "react";
import { render } from "react-dom";
import Web3Provider, { useWeb3Context, Web3Consumer } from "web3-react";
import { ethers } from "ethers";
import Web3 from "web3";
import connectors from "./connectors";
import "./styles.css";

function App() {
  return (
    <>
      <Web3Provider
        connectors={connectors}
        web3Api={Web3}
        libraryName="web3.js"
      >
        <div className="App">
          <MyComponent />
        </div>
      </Web3Provider>
    </>
  );
}

function MyComponent() {
  const context = useWeb3Context();

  if (context.error) {
    console.error("Error!");
  }

  async function sendBatchRequest() {
    const CONTRACT_ADDRESS = "0xFaC5d594548b1Ab5fB724d8011187eC51919b92e";
    const abi = require("./abi.json");
    const numberContract = new context.library.eth.Contract(
      abi,
      CONTRACT_ADDRESS
    );
    const calls = [];
    const currentNumber = await numberContract.methods.getNumber().call();

    for (
      let i = parseInt(currentNumber, 10) + 1;
      i <= parseInt(currentNumber, 10) + 3;
      i++
    ) {
      console.log(i);
      calls.push(numberContract.methods.setNumber(i).send);
    }
    let batch = new context.library.eth.BatchRequest();
    let promises = calls.map(call => {
      return new Promise((res, rej) => {
        let req = call.request({ from: context.account }, (err, txHash) => {
          console.log(txHash);
          if (err) rej(err);
          else res(txHash);
        });
        batch.add(req);
      });
    });
    batch.execute();
    return Promise.all(promises);
  }

  return (
    <React.Fragment>
      <h1>MetaMask BatchRequest Bug Demo</h1>
      <h3>(latest)</h3>

      <Web3ConsumerComponent />

      {context.error && (
        <p>An error occurred, check the console for details.</p>
      )}
      <h1>test{context.networkId}</h1>
      {Object.keys(connectors).map(connectorName => (
        <button
          key={connectorName}
          disabled={context.connectorName === connectorName}
          onClick={() => context.setConnector(connectorName)}
        >
          Activate {connectorName}
        </button>
      ))}

      <br />
      <br />

      {(context.active || (context.error && context.connectorName)) && (
        <button onClick={() => context.unsetConnector()}>
          {context.active ? "Deactivate Connector" : "Reset"}
        </button>
      )}

      {context.active && context.account && (
        <button onClick={sendBatchRequest}>Send Batch Request</button>
      )}
    </React.Fragment>
  );
}

function Web3ConsumerComponent() {
  return (
    <Web3Consumer>
      {context => {
        const { active, connectorName, account, networkId } = context;
        return (
          active && (
            <React.Fragment>
              <p>Active Connector: {connectorName}</p>
              <p>Account: {account || "None"}</p>
              <p>Network ID: {networkId}</p>
            </React.Fragment>
          )
        );
      }}
    </Web3Consumer>
  );
}

const rootElement = document.getElementById("root");
render(<App />, rootElement);
